@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# Minio Python Library for Amazon S3 Compatible Cloud Storage.
-# Copyright (C) 2016 Minio, Inc.
+# MinIO Python Library for Amazon S3 Compatible Cloud Storage.
+# Copyright (C) 2016 MinIO, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@
 
 from minio import Minio
 
-client = Minio('play.minio.io:9000',
+client = Minio('play.min.io:9000',
                access_key='Q3AM3UQ867SPQQA43P2F',
                secret_key='zuf+tfteSlswRu7BJ86wekitnifILbZam1KYY3TG')
 
